@@ -24,7 +24,7 @@ static const NML3ConfigData *
 _ip4_config_from_options(int ifindex, const char *iface, GHashTable *options)
 {
     nm_auto_unref_dedup_multi_index NMDedupMultiIndex *multi_idx = nm_dedup_multi_index_new();
-    NML3ConfigData *                                   l3cd;
+    NML3ConfigData                                    *l3cd;
 
     l3cd = nm_dhcp_utils_ip4_config_from_options(multi_idx, ifindex, iface, options);
     g_assert(NM_IS_L3_CONFIG_DATA(l3cd));
@@ -72,23 +72,23 @@ static const Option generic_options[] = {
 static void
 test_generic_options(void)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
-    const NMPlatformIP4Address *             address;
-    const NMPlatformIP4Route *               route;
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
+    const NMPlatformIP4Address              *address;
+    const NMPlatformIP4Route                *route;
     guint32                                  tmp;
-    const char *                             expected_addr        = "192.168.1.106";
-    const char *                             expected_gw          = "192.168.1.1";
-    const char *                             expected_dns1        = "216.254.95.2";
-    const char *                             expected_dns2        = "216.231.41.2";
-    const char *                             expected_search1     = "foobar.com";
-    const char *                             expected_search2     = "blah.foobar.com";
-    const char *                             expected_route1_dest = "10.1.1.5";
-    const char *                             expected_route1_gw   = "10.1.1.1";
-    const char *                             expected_route2_dest = "100.99.88.56";
-    const char *                             expected_route2_gw   = "10.1.1.1";
-    const char *const *                      strarr;
-    const in_addr_t *                        ia_arr;
+    const char                              *expected_addr        = "192.168.1.106";
+    const char                              *expected_gw          = "192.168.1.1";
+    const char                              *expected_dns1        = "216.254.95.2";
+    const char                              *expected_dns2        = "216.231.41.2";
+    const char                              *expected_search1     = "foobar.com";
+    const char                              *expected_search2     = "blah.foobar.com";
+    const char                              *expected_route1_dest = "10.1.1.5";
+    const char                              *expected_route1_gw   = "10.1.1.1";
+    const char                              *expected_route2_dest = "100.99.88.56";
+    const char                              *expected_route2_gw   = "10.1.1.1";
+    const char *const                       *strarr;
+    const in_addr_t                         *ia_arr;
     guint                                    u;
 
     options = fill_table(generic_options, NULL);
@@ -146,14 +146,14 @@ test_generic_options(void)
 static void
 test_wins_options(void)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
-    const NMPlatformIP4Address *             address;
-    const char *                             expected_wins1 = "63.12.199.5";
-    const char *                             expected_wins2 = "150.4.88.120";
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
+    const NMPlatformIP4Address              *address;
+    const char                              *expected_wins1 = "63.12.199.5";
+    const char                              *expected_wins2 = "150.4.88.120";
     static const Option data[] = {{"netbios_name_servers", "63.12.199.5 150.4.88.120"},
                                   {NULL, NULL}};
-    const in_addr_t *   ia_arr;
+    const in_addr_t    *ia_arr;
     guint               u;
 
     options = fill_table(generic_options, NULL);
@@ -173,8 +173,8 @@ test_wins_options(void)
 static void
 test_vendor_option_metered(void)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
     static const Option data[] = {{"vendor_encapsulated_options", "ANDROID_METERED"}, {NULL, NULL}};
 
     options = fill_table(generic_options, NULL);
@@ -193,10 +193,10 @@ static void
 test_parse_search_list(void)
 {
     guint8 *data;
-    char ** domains;
+    char  **domains;
 
     data    = (guint8[]){0x05, 'l', 'o', 'c', 'a', 'l', 0x00};
-    domains = nm_dhcp_lease_data_parse_search_list(data, 7);
+    domains = nm_dhcp_lease_data_parse_search_list(data, 7, NULL, 0, 0);
     g_assert(domains);
     g_assert_cmpint(g_strv_length(domains), ==, 1);
     g_assert_cmpstr(domains[0], ==, "local");
@@ -205,7 +205,7 @@ test_parse_search_list(void)
     data    = (guint8[]){0x04, 't',  'e',  's', 't', 0x07, 'e',  'x',  'a',  'm', 'p', 'l',
                       'e',  0x03, 'c',  'o', 'm', 0x00, 0xc0, 0x05, 0x03, 'a', 'b', 'c',
                       0xc0, 0x0d, 0x06, 'f', 'o', 'o',  'b',  'a',  'r',  0x00};
-    domains = nm_dhcp_lease_data_parse_search_list(data, 34);
+    domains = nm_dhcp_lease_data_parse_search_list(data, 34, NULL, 0, 0);
     g_assert(domains);
     g_assert_cmpint(g_strv_length(domains), ==, 4);
     g_assert_cmpstr(domains[0], ==, "test.example.com");
@@ -220,7 +220,7 @@ test_parse_search_list(void)
         'a',
         'd',
     };
-    domains = nm_dhcp_lease_data_parse_search_list(data, 4);
+    domains = nm_dhcp_lease_data_parse_search_list(data, 4, NULL, 0, 0);
     g_assert(!domains);
 
     data = (guint8[]){
@@ -235,7 +235,7 @@ test_parse_search_list(void)
         'a',
         'd',
     };
-    domains = nm_dhcp_lease_data_parse_search_list(data, 10);
+    domains = nm_dhcp_lease_data_parse_search_list(data, 10, NULL, 0, 0);
     g_assert(domains);
     g_assert_cmpint(g_strv_length(domains), ==, 1);
     g_assert_cmpstr(domains[0], ==, "okay");
@@ -245,8 +245,8 @@ test_parse_search_list(void)
 static void
 ip4_test_route(const NML3ConfigData *l3cd,
                guint                 route_num,
-               const char *          expected_dest,
-               const char *          expected_gw,
+               const char           *expected_dest,
+               const char           *expected_gw,
                guint                 expected_prefix)
 {
     const NMPlatformIP4Route *route;
@@ -278,12 +278,12 @@ ip4_test_route(const NML3ConfigData *l3cd,
 static void
 test_classless_static_routes_1(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
-    const char *                             expected_route2_dest = "10.0.0.0";
-    const char *                             expected_route2_gw   = "10.17.66.41";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_route2_dest = "10.0.0.0";
+    const char                              *expected_route2_gw   = "10.17.66.41";
     static const Option                      data[]               = {
         /* dhclient custom format */
         {"rfc3442_classless_static_routes", "24 192 168 10 192 168 1 1 8 10 10 17 66 41"},
@@ -303,12 +303,12 @@ test_classless_static_routes_1(void)
 static void
 test_classless_static_routes_2(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
-    const char *                             expected_route2_dest = "10.0.0.0";
-    const char *                             expected_route2_gw   = "10.17.66.41";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_route2_dest = "10.0.0.0";
+    const char                              *expected_route2_gw   = "10.17.66.41";
     static const Option                      data[]               = {
         /* dhcpcd format */
         {"classless_static_routes", "192.168.10.0/24 192.168.1.1 10.0.0.0/8 10.17.66.41"},
@@ -328,13 +328,13 @@ test_classless_static_routes_2(void)
 static void
 test_fedora_dhclient_classless_static_routes(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "129.210.177.128";
-    const char *                             expected_route1_gw   = "192.168.0.113";
-    const char *                             expected_route2_dest = "2.0.0.0";
-    const char *                             expected_route2_gw   = "10.34.255.6";
-    const char *                             expected_gateway     = "192.168.0.113";
+    const char                              *expected_route1_dest = "129.210.177.128";
+    const char                              *expected_route1_gw   = "192.168.0.113";
+    const char                              *expected_route2_dest = "2.0.0.0";
+    const char                              *expected_route2_gw   = "10.34.255.6";
+    const char                              *expected_gateway     = "192.168.0.113";
     static const Option                      data[]               = {
         /* Fedora dhclient format */
         {"classless_static_routes",
@@ -357,10 +357,10 @@ test_fedora_dhclient_classless_static_routes(void)
 static void
 test_dhclient_invalid_classless_routes_1(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
     static const Option                      data[]               = {
         /* dhclient format */
         {"rfc3442_classless_static_routes", "24 192 168 10 192 168 1 1 45 10 17 66 41"},
@@ -382,12 +382,12 @@ test_dhclient_invalid_classless_routes_1(void)
 static void
 test_dhcpcd_invalid_classless_routes_1(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "10.1.1.5";
-    const char *                             expected_route1_gw   = "10.1.1.1";
-    const char *                             expected_route2_dest = "100.99.88.56";
-    const char *                             expected_route2_gw   = "10.1.1.1";
+    const char                              *expected_route1_dest = "10.1.1.5";
+    const char                              *expected_route1_gw   = "10.1.1.1";
+    const char                              *expected_route2_dest = "100.99.88.56";
+    const char                              *expected_route2_gw   = "10.1.1.1";
     static const Option                      data[]               = {
         /* dhcpcd format */
         {"classless_static_routes", "192.168.10.0/24 192.168.1.1 10.0.adfadf/44 10.17.66.41"},
@@ -412,12 +412,12 @@ test_dhcpcd_invalid_classless_routes_1(void)
 static void
 test_dhclient_invalid_classless_routes_2(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "10.1.1.5";
-    const char *                             expected_route1_gw   = "10.1.1.1";
-    const char *                             expected_route2_dest = "100.99.88.56";
-    const char *                             expected_route2_gw   = "10.1.1.1";
+    const char                              *expected_route1_dest = "10.1.1.5";
+    const char                              *expected_route1_gw   = "10.1.1.1";
+    const char                              *expected_route2_dest = "100.99.88.56";
+    const char                              *expected_route2_gw   = "10.1.1.1";
     static const Option                      data[]               = {
         {"rfc3442_classless_static_routes", "45 10 17 66 41 24 192 168 10 192 168 1 1"},
         {NULL, NULL}};
@@ -441,12 +441,12 @@ test_dhclient_invalid_classless_routes_2(void)
 static void
 test_dhcpcd_invalid_classless_routes_2(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "10.1.1.5";
-    const char *                             expected_route1_gw   = "10.1.1.1";
-    const char *                             expected_route2_dest = "100.99.88.56";
-    const char *                             expected_route2_gw   = "10.1.1.1";
+    const char                              *expected_route1_dest = "10.1.1.5";
+    const char                              *expected_route1_gw   = "10.1.1.1";
+    const char                              *expected_route2_dest = "100.99.88.56";
+    const char                              *expected_route2_gw   = "10.1.1.1";
     static const Option                      data[]               = {
         {"classless_static_routes", "10.0.adfadf/44 10.17.66.41 192.168.10.0/24 192.168.1.1"},
         {NULL, NULL}};
@@ -472,10 +472,10 @@ test_dhcpcd_invalid_classless_routes_2(void)
 static void
 test_dhclient_invalid_classless_routes_3(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
     static const Option                      data[]               = {
         {"rfc3442_classless_static_routes", "24 192 168 10 192 168 1 1 32 128 10 17 66 41"},
         {NULL, NULL}};
@@ -496,10 +496,10 @@ test_dhclient_invalid_classless_routes_3(void)
 static void
 test_dhcpcd_invalid_classless_routes_3(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
     static Option                            data[]               = {
         {"classless_static_routes", "192.168.10.0/24 192.168.1.1 128/32 10.17.66.41"},
         {NULL, NULL}};
@@ -520,11 +520,11 @@ test_dhcpcd_invalid_classless_routes_3(void)
 static void
 test_dhclient_gw_in_classless_routes(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
-    const char *                             expected_gateway     = "192.2.3.4";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_gateway     = "192.2.3.4";
     static Option                            data[]               = {
         {"rfc3442_classless_static_routes", "24 192 168 10 192 168 1 1 0 192 2 3 4"},
         {NULL, NULL}};
@@ -544,11 +544,11 @@ test_dhclient_gw_in_classless_routes(void)
 static void
 test_dhcpcd_gw_in_classless_routes(void)
 {
-    gs_unref_hashtable GHashTable *options                        = NULL;
+    gs_unref_hashtable GHashTable           *options              = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd                 = NULL;
-    const char *                             expected_route1_dest = "192.168.10.0";
-    const char *                             expected_route1_gw   = "192.168.1.1";
-    const char *                             expected_gateway     = "192.2.3.4";
+    const char                              *expected_route1_dest = "192.168.10.0";
+    const char                              *expected_route1_gw   = "192.168.1.1";
+    const char                              *expected_gateway     = "192.2.3.4";
     static Option                            data[]               = {
         {"classless_static_routes", "192.168.10.0/24 192.168.1.1 0.0.0.0/0 192.2.3.4"},
         {NULL, NULL}};
@@ -568,13 +568,13 @@ test_dhcpcd_gw_in_classless_routes(void)
 static void
 test_escaped_domain_searches(void)
 {
-    gs_unref_hashtable GHashTable *options                    = NULL;
+    gs_unref_hashtable GHashTable           *options          = NULL;
     nm_auto_unref_l3cd const NML3ConfigData *l3cd             = NULL;
-    const char *                             expected_search0 = "host1";
-    const char *                             expected_search1 = "host2";
-    const char *                             expected_search2 = "host3";
+    const char                              *expected_search0 = "host1";
+    const char                              *expected_search1 = "host2";
+    const char                              *expected_search2 = "host3";
     static const Option data[] = {{"domain_search", "host1\\032host2\\032host3"}, {NULL, NULL}};
-    const char *const * strarr;
+    const char *const  *strarr;
     guint               u;
 
     options = fill_table(generic_options, NULL);
@@ -591,10 +591,10 @@ test_escaped_domain_searches(void)
 static void
 test_invalid_escaped_domain_searches(void)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
     static const Option data[] = {{"domain_search", "host1\\aahost2\\032host3"}, {NULL, NULL}};
-    const char *const * strarr;
+    const char *const  *strarr;
     guint               u;
 
     options = fill_table(generic_options, NULL);
@@ -612,9 +612,9 @@ test_invalid_escaped_domain_searches(void)
 static void
 test_ip4_missing_prefix(const char *ip, guint32 expected_prefix)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
-    const NMPlatformIP4Address *             address;
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
+    const NMPlatformIP4Address              *address;
 
     options = fill_table(generic_options, NULL);
     g_hash_table_insert(options, "ip_address", (gpointer) ip);
@@ -649,9 +649,9 @@ test_ip4_missing_prefix_8(void)
 static void
 test_ip4_prefix_classless(void)
 {
-    gs_unref_hashtable GHashTable *options        = NULL;
-    nm_auto_unref_l3cd const NML3ConfigData *l3cd = NULL;
-    const NMPlatformIP4Address *             address;
+    gs_unref_hashtable GHashTable           *options = NULL;
+    nm_auto_unref_l3cd const NML3ConfigData *l3cd    = NULL;
+    const NMPlatformIP4Address              *address;
 
     /* Ensure that the missing-subnet-mask handler doesn't mangle classless
      * subnet masks at all.  The handler should trigger only if the server
@@ -674,7 +674,7 @@ test_ip4_prefix_classless(void)
     G_STMT_START                                                  \
     {                                                             \
         gs_unref_bytes GBytes *b = NULL;                          \
-        const char *           p;                                 \
+        const char            *p;                                 \
         gsize                  l;                                 \
                                                                   \
         b = nm_dhcp_utils_client_id_string_to_bytes(src);         \
@@ -694,12 +694,12 @@ test_ip4_prefix_classless(void)
 static void
 test_client_id_from_string(void)
 {
-    const char * nothex       = "asdfasdfasdfasdfasdfasdfasdf";
-    const char * allhex       = "00:11:22:33:4:55:66:77:88";
+    const char  *nothex       = "asdfasdfasdfasdfasdfasdfasdf";
+    const char  *allhex       = "00:11:22:33:4:55:66:77:88";
     const guint8 allhex_bin[] = {0x00, 0x11, 0x22, 0x33, 0x04, 0x55, 0x66, 0x77, 0x88};
-    const char * somehex      = "00:11:22:33:44:55:asdfasdfasdf:99:10";
-    const char * nocolons     = "0011223344559910";
-    const char * endcolon     = "00:11:22:33:44:55:";
+    const char  *somehex      = "00:11:22:33:44:55:asdfasdfasdf:99:10";
+    const char  *nocolons     = "0011223344559910";
+    const char  *endcolon     = "00:11:22:33:44:55:";
 
     COMPARE_ID(nothex, TRUE, nothex, strlen(nothex));
     COMPARE_ID(allhex, FALSE, allhex_bin, sizeof(allhex_bin));
